# flake8-awesome

[![pypi](https://badge.fury.io/py/flake8-awesome.svg)](https://pypi.org/project/flake8-awesome)
[![Python: 3.6+](https://img.shields.io/badge/Python-3.6+-blue.svg)](https://pypi.org/project/flake8-awesome)
[![Downloads](https://img.shields.io/pypi/dm/flake8-awesome.svg)](https://pypistats.org/packages/flake8-awesome)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://en.wikipedia.org/wiki/MIT_License)

Flake8 awesome plugins pack.

## Installation

```bash
pip install flake8-awesome
```

and you have ONE dep in your requirements (pipfile, pyproject.toml)

vs

```bash
pip install flake8 flake8-builtins flake8-comprehensions flake8-eradicate # etc.
```

## Plugins

* flake8-breakpoint
* flake8-builtins
* flake8-comprehensions
* flake8-eradicate
* flake8-if-expr
* flake8-isort
* flake8-logging-format
* flake8-print
* flake8-pytest
* flake8-pytest-style
* flake8-return
* pep8-naming

## License

MIT

## Change Log

### 1.2.0 - 2019.06.10

* add flake8-pytest-style

### 1.0.0 - 2019.04.01

* add flake8-breakpoint
* add flake8-print

### 0.2.0 - 2019.02.26

* add flake8-return
* remove flake8-pie flake8-quotes

### 0.1.0

* initial
